@@ -17,41 +17,79 @@ function getContacts() {
     return [{ folder_id: activefolder, id: contactDetailId }];
 }
 
-//The menu
+// The menu
 
+register("OX_SELECTED_ITEMS_CHANGED", updateMenu);
+register("OX_menu_Change_Height", updateMenu);
+register("OX_Switched", updateMenu);
+menuarrows["com.4psa.voipnow"] = {};
 var menu = MenuNodes.createSmallButtonContext("com.4psa.voipnow.menu",
-    _("VoipNow"));
+    _("VoipNow"), "com.4psa.voipnow");
 
-var id = 0;
-function addButton(fields, title, icon, callback, noData) {
-    var buttonID = "com.4psa.voipnow." + id++;
-    MenuNodes.createSmallButton(menu, buttonID, title,
-        "plugins/com.4psa.voipnow/images/" + icon + ".png",
-        "plugins/com.4psa.voipnow/images/" + icon + "_d.png",
-        function() {
-            var collection = { objects: getContacts(), columns: fields };
-            OXCache.newRequest(null, "contacts", collection, null,
-                function(data) {
-                    var numbers = [], contacts = [];
-                    for (var i = 0; i < data.objects.length; i++) {
-                        var contact = data.objects[i];
-                        for (var j = 0; j < fields.length; j++) {
-                            if (contact[fields[j]]) {
-                                numbers.push(contact[fields[j]]);
-                                contacts.push(contact);
-                                break;
-                            }
-                        }
-                    }
-                    if (contacts.length == data.objects.length) {
-                        callback(numbers, contacts);
-                    } else {
-                        noData(numbers, contacts, data.objects);
-                    }
-                });
-        });
-    return buttonID;
+/**
+ * A menu section which selects one of many entries.
+ * @param {String} module A unique module name for internal use.
+ * @param {I18nString} caption The caption of the menu section.
+ * @param {Array of I18nString} names An array with the section's entries.
+ * @param {Array} values An array with one value for each entry in the #names
+ * array. Must have the same length as #names.
+ * @type String
+ * @return The unique ID of the section, which is required by changeDisplay etc.
+ */
+function MenuSelection(module, caption, names, values) {
+    this.module = module;
+    this.count = names.length;
+    this.id = module + ".menuselection" + MenuSelection.id++;
+    this.index = 0;
+    var menu = MenuNodes.createSmallButtonContext(this.id, caption, module);
+    menu.body.parentNode.parentNode.className = "backgroundheight";
+    if (!(module in menuarrows)) menuarrows[module] = {};
+    var Self = this;
+    for (var i = 0; i < this.count; i++) {
+        var id2 = this.id + "." + i;
+        var element = newnode("tr", i ? { display: "none" } : 0,
+            { id: id2 + "_active" },
+            [newnode("td", 0, { className: "height16 background-color-PMG-selection-elements padding7px" },
+                [newnode("div", 0, { className: "height16" },
+                    [addTranslated(names[i])])])]);
+        allnodes[element.id] = element;
+        menu.body.appendChild(element);
+        var element2 = newnode("tr", i ? 0 : { display: "none" },
+            { id: id2 + "_notactive" },
+            [newnode("td", 0, { className: "height16 padding7px" },
+                [newnode("div", 0, { className: "height16" },
+                    [addTranslated(names[i])])])]);
+        allnodes[element2.id] = element2;
+        element2.onclick = (function(index, value) {
+            return function() {
+                Self.set(index);
+                Self.onChange(value);
+            };
+        })(i, values[i]);
+        menu.body.appendChild(element2);
+    }
+    addMenuNode(menu.node, MenuNodes.FIXED, 30);
+    MenuSelection.instances[this.id] = this;
 }
+MenuSelection.id = 0;
+MenuSelection.instances = {};
+MenuSelection.update = function() {
+    for (var i in MenuSelection.instances) MenuSelection.instances[i].set();
+};
+register("OX_SELECTED_ITEMS_CHANGED", MenuSelection.update);
+register("OX_menu_Change_Height", MenuSelection.update);
+register("OX_Switched", MenuSelection.update);
+MenuSelection.prototype.set = function(index) {
+    if (index !== undefined) this.index = index;
+    menuglobalzaehler = 0;
+    menuarrows[this.module][this.id] = [];
+    for (var i = 0; i < this.count; i++) {
+        menu_display_views(this.module, this.id, true, i == this.index,
+                           this.id + "." + i);
+    }
+};
+MenuSelection.prototype.onChange = emptyFunction;
+
 
 function ManualPulldownMenu(trigger) {
     PopupMenu.call(this);
@@ -264,33 +302,42 @@ VoipCallDialog.prototype.paintNumbers = function(contact) {
 		var i = 0, $l = phoneFields.length - 2, first = true, border = "1px solid #aaa";
 		for (; i < $l; i++) {
 			var key = phoneFields[i], name = phoneLabels[i], value = contact[key];
-			if (value) {
-				// add (via closure)
-				var self = this;
-				(function(name, value) {
-					// create div
-					var div = newnode("div", {
-						cursor: "pointer", lineHeight: "2em", backgroundColor: "white",
-						borderBottom: border, paddingLeft: "10px"
-					}, 0, [addTranslated(name), newtext(": "), newnode("b", 0, 0, [newtext(value)])]);
-					// first?
-					if (first) { div.style.borderTop = border; first = false; }
-					// add listeners
-					addDOMEvent(div, "mouseover", function() { div.className = "background-color-PMG-selection-elements"; });
-					addDOMEvent(div, "mouseout", function() { div.className = ""; });
-					addDOMEvent(div, "click", function() {
-						self.box.value = value;
-						self.box.focus();
-					});
-					addDOMEvent(div, "dblclick", function() {
-						self.box.value = value;
-						self.call();
-					});
-					numbers.appendChild(div);
-				})(name, value);
-			}
+			if (value) addNumber(name, value);
+		}
+		if (contact.unnamedNumbers) {
+		    for (var i = 0; i < contact.unnamedNumbers.length; i++) {
+		        addNumber("", contact.unnamedNumbers[i]);
+		    }
 		}
 	}
+    var self = this;
+	function addNumber(name, value) {
+        // create div
+	    var children = [];
+	    if (name) {
+	        children.push(addTranslated(name));
+	        children.push(newtext(": "));
+	    }
+	    children.push(newnode("b", 0, 0, [newtext(value)]));
+        var div = newnode("div", {
+            cursor: "pointer", lineHeight: "2em", backgroundColor: "white",
+            borderBottom: border, paddingLeft: "10px"
+        }, 0, children);
+        // first?
+        if (first) { div.style.borderTop = border; first = false; }
+        // add listeners
+        addDOMEvent(div, "mouseover", function() { div.className = "background-color-PMG-selection-elements"; });
+        addDOMEvent(div, "mouseout", function() { div.className = ""; });
+        addDOMEvent(div, "click", function() {
+            self.box.value = value;
+            self.box.focus();
+        });
+        addDOMEvent(div, "dblclick", function() {
+            self.box.value = value;
+            self.call();
+        });
+        numbers.appendChild(div);
+    }
 };
 
 VoipCallDialog.prototype.paintDialer = function() {
@@ -319,7 +366,7 @@ VoipCallDialog.prototype.paintDialer = function() {
 	// icon
 	this.icon = newnode("img", {
 		width: "16px", height: "16px", marginLeft: "10px", cursor: "pointer"
-	}, { src: "plugins/com.4psa.voipnow/images/call.png" });
+	}, { src: urlify("plugins/com.4psa.voipnow/images/call.png") });
 	this.dialer.appendChild(this.icon);
 	// add listener
 	addDOMEvent(this.icon, "click", function() {
@@ -357,6 +404,7 @@ VoipCallDialog.prototype.call = function() {
                 "&session=" + session, getPhones(),
                 // success
                 function() {
+                    //#, c-format
     				var message = format(_("Connection established. Please check your SIP client in order to answer the call. Afterwards, the number %s will be automatically called."), number);
     				self.log.appendChild(newnode("div", { color: "#050", fontWeight: "bold" }, 0, [addTranslated(message)]));
     			},
@@ -389,7 +437,8 @@ register("PAINT_CONTACT", function(e) {
 		if (e.contact.distribution_list === null) {
 			
 			// create image
-			var img = newnode("img", { cursor: "pointer" }, { src: "plugins/com.4psa.voipnow/images/call.png" });
+			var img = newnode("img", { cursor: "pointer" },
+			    { src: urlify("plugins/com.4psa.voipnow/images/call.png") });
 			// add listener
 			addDOMEvent(img, "click", function() {
 				// ensure necessary data (phone data might be missing)
@@ -431,8 +480,8 @@ register("PAINT_CONTACT", function(e) {
 // ---------------------------------------------
 
 MenuNodes.createSmallButton(menu, "com.4psa.voipnow.call", _("Call"),
-    "plugins/com.4psa.voipnow/images/call.png",
-    "plugins/com.4psa.voipnow/images/call_d.png",
+    urlify("plugins/com.4psa.voipnow/images/call.png"),
+    urlify("plugins/com.4psa.voipnow/images/call_d.png"),
     function() {
         if (PopupMenu.last == callMenu) {
             PopupMenu.last = null;
@@ -488,20 +537,73 @@ addDOMEvent(customPhoneInput, "keypress", function(e) {
 });
 
 // Sending faxes
+
 var faxFields = ["fax_business", "fax_home", "fax_other"];
-var fax = addButton(faxFields, _("Fax"), "fax", function(faxes, contacts) {
-    newFax(faxes);
-}, function(faxes, contacts, allContacts) {
-    if (contacts.length) {
-        ox.Configuration.error(
-            _("Not all selected contacts have an associated fax number."));
-    } else {
-        ox.Configuration.error(
-            ngettext("The selected contact has no associated fax number.",
-                "The selected contacts have no associated fax number.",
-                allContacts.length));
-    }
-});
+MenuNodes.createSmallButton(menu, "com.4psa.voipnow.fax", _("Fax"),
+    urlify("plugins/com.4psa.voipnow/images/fax.png"),
+    urlify("plugins/com.4psa.voipnow/images/fax_d.png"),
+    function() {
+        switch (activemodule) {
+            case "contacts":
+                var collection = { objects: getContacts(), columns: faxFields };
+                OXCache.newRequest(null, "contacts", collection, null,
+                    function(data) {
+                        var numbers = [], contacts = [];
+                        for (var i = 0; i < data.objects.length; i++) {
+                            var contact = data.objects[i];
+                            for (var j = 0; j < faxFields.length; j++) {
+                                if (contact[faxFields[j]]) {
+                                    numbers.push(contact[faxFields[j]]);
+                                    contacts.push(contact);
+                                    break;
+                                }
+                            }
+                        }
+                        if (contacts.length == data.objects.length) {
+                            newFax(numbers);
+                        } else {
+                            if (contacts.length) {
+                                ox.Configuration.error(
+                                    _("Not all selected contacts have an associated fax number."));
+                            } else {
+                                ox.Configuration.error(
+                                    ngettext("The selected contact has no associated fax number.",
+                                        "The selected contacts have no associated fax number.",
+                                        data.objects.length));
+                            }
+                        }
+                    });
+                break;
+            case "infostore":
+                var requests = new Array(oLastSelectedInfoObject.length);
+                for (var i = 0; i < oLastSelectedInfoObject.length; i++) {
+                    requests[i] = {
+                        module: "infostore", action: "get",
+                        folder: oLastSelectedInfoObject[i].folder,
+                        id: oLastSelectedInfoObject[i].id
+                    };
+                }
+                ox.JSON.put(AjaxRoot + "/multiple?session=" + session, requests,
+                    function(data) {   
+                        var items = new Array(data.length);
+                        var allFiles = true;
+                        for(var i = 0; i < data.length; data++) {
+                            var obj = data[i].data;
+                            if (obj.file_size <= 0) allFiles = false;
+                            items[i] = {
+                                filename: obj.filename,
+                                size: obj.file_size,
+                                content_type: obj.file_mimetype,
+                                id: obj.id
+                            };
+                        }
+                        if (allFiles) newFax(0, items);
+                    });
+                break;
+            default:
+                newFax();
+        }
+    });
 
 function newFax(faxes, attachments) {
     var url = "newMail.html#to=" +
@@ -544,7 +646,7 @@ function newFax(faxes, attachments) {
                     w.setTimeout(function() {
                         w.triggerEvent("OX_New_Error", 4,
                             _("Please specify at least one recipient fax number."));
-                    });
+                    }, 0);
                     return;
                 }
                 var a = new w.Array();
@@ -572,6 +674,14 @@ function newFax(faxes, attachments) {
     }
 }
 
+// Call history menu entry
+MenuNodes.createSmallButton(menu, "com.4psa.voipnow.callhistory",
+    _("Call history"), "", "",
+    function() {
+        triggerEvent("OX_Switch_View", "com.4psa.voipnow.callhistory");
+    });
+
+
 // My Location
 function Updatable() {
     this.callbacks = [];
@@ -615,9 +725,7 @@ function getPhones() {
 }
 
 MenuNodes.createSmallButton(menu, "com.4psa.voipnow.mylocation",
-    _("My location"),
-    getFullImgSrc("img/arrows/sort_down.gif"),
-    getFullImgSrc("img/arrows/sort_down.gif"),
+    _("My location"), "", "",
     function() {
         if (PopupMenu.last == locationMenu) {
             PopupMenu.last = null;
@@ -636,6 +744,15 @@ locations.register(function(locations, join) {
     active.update(active.value, join.add());
     config.modules["com.4psa.voipnow"].gui.locations = locations;
 });
+$("com.4psa.voipnow.mylocation").oxSubmenu = function(menu) {
+    locations.wait(function(locations) {
+        for (var i in locations) {
+            menu.addItem(new MenuItem(noI18n(locations[i].name), (function(id) {
+                return function() { active.update(id); };
+            })(i)));
+        }
+    });
+};
 var oldPhones;
 active.register(function(active, join) {
     function equals(a, b) {
@@ -682,69 +799,299 @@ phones.wait(function(defaultPhones) {
     locations.update(gui.locations);
 });
 
+// Call History
+
+function CallHistory() {
+    this.id = 0;
+    this.start = this.end = Math.floor(now() / 864e5) * 864e5; // ms/day
+    this.data = [];
+    // number of calls on the last queried day (which will be queried again)
+    this.today = 0;
+    /*
+     *  The event "Update" fires when new calls are available.
+     */  
+    this.events = new Events();
+    var Self = this;
+    this.update_cb = function() { Self.update(); };
+    this.update();
+}
+
+CallHistory.prototype = {
+    getData: function(start, end, callback) {
+        var Self = this;
+        ox.JSON.get(AjaxRoot + "/com.4psa.voipnow?action=callreport&start=" +
+            start + "&end=" + end + "&session=" + session, cb);
+        function cb(reply) {
+            Self.updating = false;
+            var calls = reply.data.calls;
+            for (var i = 0; i < calls.length; i++) {
+                var call = calls[i];
+                call.id = ++Self.id;
+                call.number = call.flow == "out" ? call.source // TODO swap
+                                                 : call.destination;
+            }
+            callback(calls.reverse());
+        }
+    },
+    update: function(callback) {
+        var Self = this;
+        var end = Math.floor(now() / 864e5) * 864e5; // ms/day
+        this.getData(this.end, end, cb);
+        function cb(calls) {
+            Self.data = Self.data.concat(calls.slice(Self.today));
+            if (Self.end == end) {
+                if (Self.today != calls.length) {
+                    Self.today = calls.length;
+                    Self.events.trigger("Update");
+                }
+            } else {
+                var i = Self.today;
+                while (i < calls.length && calls[i].startDate < end) i++;
+                Self.today = calls.length - i;
+                Self.end = end;
+                Self.events.trigger("Update");
+            }
+            if (callback) callback();
+        }
+    },
+    get: function(days, callback) {
+        var start = (Math.floor(now() / 864e5) - days + 1) * 864e5; // ms/day
+        if (start < this.start) {
+            this.data = [];
+            this.start = this.end = start;
+            this.today = 0;
+        }
+        this.update(callback);
+    }
+};
+
+var history = new CallHistory();
+register("OX_Refresh", function() { history.update(); });
+
+// TODO filter: days
+
+function View(title, history) {
+    this.history = history;
+    this.flow = 0;
+    this.result = 1;
+    var Self = this;
+    
+    var s = new MenuSelection("com.4psa.voipnow", _("Status"),
+        [_("Missed"), _("Taken"), _("All")], [1, 0, 2]);
+    s.onChange = function(result) {
+        Self.result = result;
+        Self.update();
+    };
+    changeDisplay("com.4psa.voipnow.callhistory", s.id);
+    s = new MenuSelection("com.4psa.voipnow", _("Calls"),
+        [_("Incoming"), _("Outgoing"), _("All")], [0, 1, 2]);
+    s.onChange = function(flow) {
+        Self.flow = flow;
+        Self.update();
+    };
+    changeDisplay("com.4psa.voipnow.callhistory", s.id);
+    
+    registerView("com.4psa.voipnow.callhistory", function() {
+        showNode("modules");
+        if (!Self.initialized && Self.init) Self.init();
+        ox.Configuration.View.i18n.callback = title;
+        ox.Configuration.View.i18n.update();
+        ox.Configuration.View.i18n.enable();
+        $("modules.content").appendChild(Self.content);
+    }, function() {
+        ox.Configuration.View.current = Self;
+        Self.enter();
+    }, function() {
+        Self.leave();
+        ox.Configuration.View.current = null;
+    }, function() {
+        $("modules.content").removeChild(Self.content);
+        ox.Configuration.View.i18n.disable();
+        hideNode("modules");
+    }, function() {
+        Self.leave();
+        Self.enter();
+    }
+    );
+    changeDisplay("com.4psa.voipnow.callhistory", "menu_nothing");
+    this.update_cb = function() { Self.update(); };
+}
+
+View.prototype = {
+    init: function() {
+        var list = this.list = new LiveGrid([
+            {
+                text: noI18n(""),
+                width: "26px",
+                sortable: true,
+                id: "flow",
+                clear: function(div) {
+                    var src = getFullImgSrc("img/dumy.gif");
+                    if (div.firstChild) {
+                        div.firstChild.src = src;
+                    } else {
+                        div.appendChild(newnode("img",
+                            { verticalAlign: "middle" }, { src: src }));
+                    }
+                },
+                set: function(div, data) {
+                    var src = urlify("plugins/com.4psa.voipnow/images/" +
+                        (data.flow == "in" ? "incoming.png"
+                                           : "outgoing.png"));
+                    if (div.firstChild) {
+                        div.firstChild.src = src;
+                    } else {
+                        div.appendChild(newnode("img",
+                            { verticalAlign: "middle" }, { src: src }));
+                    }
+                    div.parentNode.parentNode.style.color = 
+                        data.answerDate > 0 ? "" : "maroon";
+                }
+            },
+            {
+                text: _("Number"),
+                style: { fontWeight: "bold" },
+                index: "number",
+                width: "10em",
+                sortable: true,
+                id: "number",
+                clear: LiveGrid.makeClear(""),
+                set: LiveGrid.defaultSet
+            },
+            {
+                text: _("Time"),
+                index: "startDate",
+                width: "10em",
+                sortable: true,
+                id: "startDate",
+                clear: LiveGrid.makeClear(""),
+                set: LiveGrid.dateSetTime
+            },
+            {
+                text: _("Duration"),
+                index: "duration",
+                sortable: true,
+                id: "duration",
+                clear: LiveGrid.makeClear(""),
+                set: function(div, data) {
+                    data = Number(data);
+                    var d = new Date(data * 1000);
+                    var text;
+                    if (data <= 0) text = "";
+                    //#. Abbreviation for '%d seconds'
+                    //#, c-format
+                    else if (data < 60) text = format(_("%d s"), data)();
+                    else if (data < 3600) text = formatDateTime("m:ss", d);
+                    else if (data < 864e5) text = formatDateTime("H:mm:ss", d);
+                    else text = getInterval(d);
+                    LiveGrid.defaultSet(div, text);
+                }
+            },
+        ], new Selection());
+        list.sort = LiveGrid.localSort;
+        list.sort_id = "startDate";
+        list.sort_order = "desc";
+        list.events.register("Activated", function(ids) {
+            if (!ids.length) return;
+            var numbers = [];
+            list.storage.newIterate(ids, emptyFunction,
+                function(i, call) { numbers.push(call.number); },
+                function() {
+                    callDialog.show({ display_name: numbers.join(", "),
+                                      unnamedNumbers: numbers });
+                });
+        });
+        var list_parent = newnode("div", {
+            position: "absolute", top: "1.6em", bottom: 0, overflow: "auto",
+            width: "100%"
+        });
+        this.content = newnode("div", {
+            position: "absolute", left: 0, top: 0, right: 0, bottom: 0,
+            overflow: "hidden"
+        }, 0, [list.getHeader(), list_parent]);
+        list.getTable(list_parent);
+        this.initialized = true;
+    },
+    enter: function() {
+        var Self = this;
+        Self.history.events.register("Update", Self.update_cb);
+        this.history.get(10, function() {
+            oldMissedCalls = missedCalls;
+            setMissedCalls(0);
+        });
+    },
+    leave: function() {
+        this.history.events.unregister("Update", this.update_cb);
+    },
+    resize: function() {
+    },
+    update: function() {
+        var storage = new Storage(0, [], 0, 0, 0, 0,
+            function(x) { return x.id; });
+        var all = this.history.data, filtered = [];
+        for (var i = 0; i < all.length; i++) {
+            var call = all[i];
+            if (   Number(call.flow != "out") != this.flow
+                && Number(call.answerDate > 0) != this.result)
+            {
+                filtered.push(call);
+            }
+        }
+        storage.append(filtered);
+        this.list.enable(storage);
+        this.list.sort(this.list.sort_id, this.list.sort_order);
+    }
+};
+
+var callHistory = new View(_("Call history"), history);
+
+var callHistoryImg =
+    allnodes["com.4psa.voipnow.callhistory"].firstChild.firstChild.firstChild;
+function setMissedCalls(missed) {
+    callHistoryImg.src = getFullImgSrc(missed ? "img/mail/email_priohigh.gif"
+                                              : "img/dummy.gif");
+}
+
+var oldMissedCalls = 0, missedCalls = 0;
+history.events.register("Update", function() {
+    missedCalls = 0;
+    for (var i = history.data.length - 1; i >= 0; i--) {
+        if (history.data[i].startDate < history.end) break;
+        if (!(history.data[i].answerDate > 0)) missedCalls++;
+    }
+    setMissedCalls(missedCalls > oldMissedCalls);
+});
+
+// Menu
+
 addMenuNode(menu.node, MenuNodes.DYNAMIC, 3);
-changeDisplay("contacts", "com.4psa.voipnow.menu");
-if (currentpath2[0] == "contacts") showNode("com.4psa.voipnow.menu");
-menuarrows["com.4psa.voipnow"] = {};
-register("OX_SELECTED_ITEMS_CHANGED", function() {
+function updateMenu() {
     menuglobalzaehler = 0;
     menuarrows["com.4psa.voipnow"]["com.4psa.voipnow.menu"] = [];
     // call
    	menu_display_contents("com.4psa.voipnow", "com.4psa.voipnow.menu",
-   		menucountselected == 1, "com.4psa.voipnow.call");
+   		activemodule == "contacts" ? menucountselected == 1
+   		                           : HideMenuContent,
+	    "com.4psa.voipnow.call");
     // fax
     menu_display_contents("com.4psa.voipnow", "com.4psa.voipnow.menu",
-        menucountselected > 0, fax);
+        true, "com.4psa.voipnow.fax");
     // location
     menu_display_contents("com.4psa.voipnow", "com.4psa.voipnow.menu",
         true, "com.4psa.voipnow.mylocation");
-});
-
-//Send faxes from InfoStore
-var menuInfoStore = MenuNodes.createSmallButtonContext(
-    "com.4psa.voipnow.menuinfostore", _("VoipNow"));
-
-MenuNodes.createSmallButton(menuInfoStore, "com.4psa.voipnow.faxinfoitem",
-    _("Fax"),
-    "plugins/com.4psa.voipnow/images/fax.png",
-    "plugins/com.4psa.voipnow/images/fax_d.png",
-    function() {
-        var requests = new Array(oLastSelectedInfoObject.length);
-        for (var i = 0; i < oLastSelectedInfoObject.length; i++) {
-            requests[i] = {
-                module: "infostore", action: "get",
-                folder: oLastSelectedInfoObject[i].folder,
-                id: oLastSelectedInfoObject[i].id
-            };
-        }
-        ox.JSON.put(AjaxRoot + "/multiple?session=" + session, requests,
-            function(data) {   
-                var items = new Array(data.length);
-                var allFiles = true;
-                for(var i = 0; i < data.length; data++) {
-                    var obj = data[i].data;
-                    if (obj.file_size <= 0) allFiles = false;
-                    items[i] = {
-                        filename: obj.filename,
-                        size: obj.file_size,
-                        content_type: obj.file_mimetype,
-                        id: obj.id
-                    };
-                }
-                if (allFiles) newFax(0, items);
-            });
-    });
-addMenuNode(menuInfoStore.node, MenuNodes.DYNAMIC, 3);
-changeDisplay("infostore", "com.4psa.voipnow.menuinfostore");
-if (currentpath2[0] == "infostore") showNode("com.4psa.voipnow.menuinfostore");
-menuarrows["com.4psa.voipnow.infostore"] = {};
-register("OX_SELECTED_ITEMS_CHANGED", function() {
-    menuglobalzaehler = 0;
-    menuarrows["com.4psa.voipnow.infostore"]["com.4psa.voipnow.menuinfostore"] = [];
-    menu_display_contents("com.4psa.voipnow.infostore",
-        "com.4psa.voipnow.menuinfostore", menucountselected > 0,
-        "com.4psa.voipnow.faxinfoitem");
-});
+    // call history
+    menu_display_contents("com.4psa.voipnow", "com.4psa.voipnow.menu",
+        true, "com.4psa.voipnow.callhistory");
+}
+var allModules = { portal: 1, mail: 1, calendar: 1, contacts: 1, tasks: 1,
+    infostore: 1, messaging: 1, "com.4psa.voipnow.callhistory": 1 };
+for (var i in allModules) changeDisplay(i, "com.4psa.voipnow.menu");
+if (currentpath2[0] in allModules) {
+    showNode("com.4psa.voipnow.menu");
+    updateMenu();
+    showArrowPopUpMenu("com.4psa.voipnow.menu.enhancement",
+                       "com.4psa.voipnow.menu", "com.4psa.voipnow");
+}
 
 // Icons in mail lists
 temporary.lists.mail.addIcon({
@@ -760,7 +1107,7 @@ temporary.lists.mail.addIcon({
             case "fax":
                 return "/plugins/com.4psa.voipnow/images/fax.png";
             default:
-                return "img/dummy.png";
+                return "img/dummy.gif";
         }
     }
 });
@@ -812,6 +1159,7 @@ function updatePhones() {
                     //#. external phone label
                     //#. %1$s is the phone number
                     //#. %2$s is the field name in the contact
+                    //#, c-format
                     _("%1$s (%2$s)"), phoneLabels[i],
                     noI18n(userdata[i]))), userdata[i]);
                 defaultPhones.phones[userdata[i]] = false;
